@@ -12,7 +12,7 @@ const errFn = universalify.fromCallback(function (cb) {
 
 test('callback function works with callbacks', t => {
   t.plan(4)
-  fn.call({a: 'a'}, 1, 2, (err, arr) => {
+  fn.call({ a: 'a' }, 1, 2, (err, arr) => {
     t.ifError(err, 'should not error')
     t.is(arr[0].a, 'a')
     t.is(arr[1], 1)
@@ -23,14 +23,14 @@ test('callback function works with callbacks', t => {
 
 test('callback function works with promises', t => {
   t.plan(3)
-  fn.call({a: 'a'}, 1, 2)
-  .then(arr => {
-    t.is(arr[0].a, 'a')
-    t.is(arr[1], 1)
-    t.is(arr[2], 2)
-    t.end()
-  })
-  .catch(t.end)
+  fn.call({ a: 'a' }, 1, 2)
+    .then(arr => {
+      t.is(arr[0].a, 'a')
+      t.is(arr[1], 1)
+      t.is(arr[2], 2)
+      t.end()
+    })
+    .catch(t.end)
 })
 
 test('callback function error works with callbacks', t => {
@@ -45,12 +45,12 @@ test('callback function error works with callbacks', t => {
 test('callback function error works with promises', t => {
   t.plan(2)
   errFn()
-  .then(arr => t.end('Promise should not resolve'))
-  .catch(err => {
-    t.assert(err, 'should error')
-    t.is(err.message, 'test')
-    t.end()
-  })
+    .then(() => t.end('Promise should not resolve'))
+    .catch(err => {
+      t.assert(err, 'should error')
+      t.is(err.message, 'test')
+      t.end()
+    })
 })
 
 test('fromCallback() sets correct .name', t => {
